"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RecordLockingProvider = exports.RecordLockingContext = void 0;
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _reactHooks = require("@apollo/react-hooks");
var _RecordLocking = require("../domain/RecordLocking");
var _appAdmin = require("@webiny/app-admin");
var RecordLockingContext = exports.RecordLockingContext = /*#__PURE__*/_react.default.createContext({});
var isSameArray = function isSameArray(existingRecords, newRecords) {
  if (existingRecords.length !== newRecords.length) {
    return false;
  }
  return existingRecords.every(function (record) {
    return newRecords.some(function (newRecord) {
      return newRecord.id === record.id && newRecord.savedOn === record.savedOn;
    });
  });
};
var RecordLockingProvider = exports.RecordLockingProvider = function RecordLockingProvider(props) {
  var client = (0, _reactHooks.useApolloClient)();
  var _useState = (0, _react.useState)(false),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    loading = _useState2[0],
    setLoading = _useState2[1];
  var recordLocking = (0, _react.useMemo)(function () {
    return (0, _RecordLocking.createRecordLocking)({
      client: client,
      setLoading: setLoading
    });
  }, []);
  var _useStateIfMounted = (0, _appAdmin.useStateIfMounted)(null),
    _useStateIfMounted2 = (0, _slicedToArray2.default)(_useStateIfMounted, 2),
    error = _useStateIfMounted2[0],
    setError = _useStateIfMounted2[1];
  var _useStateIfMounted3 = (0, _appAdmin.useStateIfMounted)([]),
    _useStateIfMounted4 = (0, _slicedToArray2.default)(_useStateIfMounted3, 2),
    records = _useStateIfMounted4[0],
    _setRecords = _useStateIfMounted4[1];
  var setRecordsIfNeeded = (0, _react.useCallback)(function (newRecords) {
    var sameArray = isSameArray(records, newRecords);
    if (sameArray) {
      return;
    }
    _setRecords(newRecords);
  }, [records]);
  var value = {
    updateEntryLock: async function updateEntryLock(params) {
      var result = await recordLocking.updateEntryLock(params);
      if (result.error) {
        setError(result.error);
        return;
      }
      var target = result.data;
      if (!target?.id) {
        setError({
          message: "No data returned from server.",
          code: "NO_DATA"
        });
        return;
      }
      _setRecords(function (prev) {
        return prev.map(function (item) {
          if (item.entryId === target.id) {
            return (0, _objectSpread2.default)((0, _objectSpread2.default)({}, item), {}, {
              $locked: result.data
            });
          }
          return item;
        });
      });
    },
    unlockEntry: async function unlockEntry(params) {
      return await recordLocking.unlockEntry(params);
    },
    unlockEntryForce: async function unlockEntryForce(params) {
      return await recordLocking.unlockEntry(params, true);
    },
    isLockExpired: function isLockExpired(input) {
      return recordLocking.isLockExpired(input);
    },
    isRecordLocked: function isRecordLocked(record) {
      if (!record) {
        return false;
      }
      return recordLocking.isRecordLocked(record);
    },
    getLockRecordEntry: function getLockRecordEntry(id) {
      return recordLocking.getLockRecordEntry(id);
    },
    removeEntryLock: function removeEntryLock(params) {
      return recordLocking.removeEntryLock(params);
    },
    fetchLockRecord: async function fetchLockRecord(params) {
      try {
        return await recordLocking.fetchLockRecord(params);
      } catch (ex) {
        return {
          data: null,
          error: ex
        };
      }
    },
    fetchLockedEntryLockRecord: async function fetchLockedEntryLockRecord(params) {
      return recordLocking.fetchLockedEntryLockRecord(params);
    },
    setRecords: async function setRecords(folderId, type, newRecords) {
      setRecordsIfNeeded(newRecords);
      var result = await recordLocking.setRecords(folderId, type, newRecords);
      if (!result) {
        return;
      }
      _setRecords(result);
    },
    error: error,
    records: records,
    loading: loading
  };
  return /*#__PURE__*/_react.default.createElement(RecordLockingContext.Provider, Object.assign({}, props, {
    value: value
  }));
};

//# sourceMappingURL=RecordLockingProvider.js.map